@@ -13,6 +13,9 @@ EXTENSIONS = {
     'bat': {'text', 'batch'},
     'bats': {'text', 'shell', 'bash', 'bats'},
     'bazel': {'text', 'bazel'},
+    'bb': {'text', 'bitbake'},
+    'bbappend': {'text', 'bitbake'},
+    'bbclass': {'text', 'bitbake'},
     'beancount': {'text', 'beancount'},
     'bib': {'text', 'bib'},
     'bmp': {'binary', 'image', 'bitmap'},
@@ -43,6 +46,7 @@ EXTENSIONS = {
     'cson': {'text', 'cson'},
     'css': {'text', 'css'},
     'csv': {'text', 'csv'},
+    'csx': {'text', 'c#', 'c#script'},
     'cu': {'text', 'cuda'},
     'cue': {'text', 'cue'},
     'cuh': {'text', 'cuda'},
@@ -75,6 +79,8 @@ EXTENSIONS = {
     'feature': {'text', 'gherkin'},
     'fish': {'text', 'fish'},
     'fits': {'binary', 'fits'},
+    'fs': {'text', 'f#'},
+    'fsx': {'text', 'f#', 'f#script'},
     'gd': {'text', 'gdscript'},
     'gemspec': {'text', 'ruby'},
     'geojson': {'text', 'geojson', 'json'},
@@ -319,6 +325,7 @@ NAMES = {
     '.csslintrc': EXTENSIONS['json'] | {'csslintrc'},
     '.dockerignore': {'text', 'dockerignore'},
     '.editorconfig': {'text', 'editorconfig'},
+    '.envrc': EXTENSIONS['bash'],
     '.flake8': EXTENSIONS['ini'] | {'flake8'},
     '.gitattributes': {'text', 'gitattributes'},
     '.gitconfig': EXTENSIONS['ini'] | {'gitconfig'},
@@ -343,6 +350,8 @@ NAMES = {
     '.zshrc': EXTENSIONS['zsh'],
     '.zshenv': EXTENSIONS['zsh'],
     'AUTHORS': EXTENSIONS['txt'],
+    'bblayers.conf': EXTENSIONS['bb'],
+    'bitbake.conf': EXTENSIONS['bb'],
     'BUILD': EXTENSIONS['bzl'],
     'Cargo.toml': EXTENSIONS['toml'] | {'cargo'},
     'Cargo.lock': EXTENSIONS['toml'] | {'cargo-lock'},
@@ -354,6 +363,7 @@ NAMES = {
     'copy.bara.sky': EXTENSIONS['bzl'],
     'COPYING': EXTENSIONS['txt'],
     'Dockerfile': {'text', 'dockerfile'},
+    'direnvrc': EXTENSIONS['bash'],
     'Gemfile': EXTENSIONS['rb'],
     'Gemfile.lock': {'text'},
     'GNUmakefile': EXTENSIONS['mk'],
